@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -137,6 +137,42 @@ class AutoMlAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return AutoMlClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> AutoMlTransport:
         """Returns the transport used by the client instance.
@@ -209,6 +245,34 @@ class AutoMlAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a dataset.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_create_dataset():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                dataset = automl_v1.Dataset()
+                dataset.translation_dataset_metadata.source_language_code = "source_language_code_value"
+                dataset.translation_dataset_metadata.target_language_code = "target_language_code_value"
+
+                request = automl_v1.CreateDatasetRequest(
+                    parent="parent_value",
+                    dataset=dataset,
+                )
+
+                # Make the request
+                operation = client.create_dataset(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.CreateDatasetRequest, dict]):
                 The request object. Request message for
@@ -240,7 +304,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, dataset])
         if request is not None and has_flattened_params:
@@ -297,6 +361,25 @@ class AutoMlAsyncClient:
     ) -> dataset.Dataset:
         r"""Gets a dataset.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_get_dataset():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.GetDatasetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_dataset(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.GetDatasetRequest, dict]):
                 The request object. Request message for
@@ -323,7 +406,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -380,6 +463,26 @@ class AutoMlAsyncClient:
     ) -> pagers.ListDatasetsAsyncPager:
         r"""Lists datasets in a project.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_list_datasets():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.ListDatasetsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_datasets(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.ListDatasetsRequest, dict]):
                 The request object. Request message for
@@ -407,7 +510,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -471,6 +574,29 @@ class AutoMlAsyncClient:
     ) -> gca_dataset.Dataset:
         r"""Updates a dataset.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_update_dataset():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                dataset = automl_v1.Dataset()
+                dataset.translation_dataset_metadata.source_language_code = "source_language_code_value"
+                dataset.translation_dataset_metadata.target_language_code = "target_language_code_value"
+
+                request = automl_v1.UpdateDatasetRequest(
+                    dataset=dataset,
+                )
+
+                # Make the request
+                response = client.update_dataset(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.UpdateDatasetRequest, dict]):
                 The request object. Request message for
@@ -504,7 +630,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([dataset, update_mask])
         if request is not None and has_flattened_params:
@@ -559,6 +685,30 @@ class AutoMlAsyncClient:
         completes, and ``delete_details`` in the
         [metadata][google.longrunning.Operation.metadata] field.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_delete_dataset():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.DeleteDatasetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_dataset(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.DeleteDatasetRequest, dict]):
                 The request object. Request message for
@@ -596,7 +746,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -671,6 +821,34 @@ class AutoMlAsyncClient:
            in the [response][google.longrunning.Operation.response]
            field when it completes.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_import_data():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                input_config = automl_v1.InputConfig()
+                input_config.gcs_source.input_uris = ['input_uris_value_1', 'input_uris_value_2']
+
+                request = automl_v1.ImportDataRequest(
+                    name="name_value",
+                    input_config=input_config,
+                )
+
+                # Make the request
+                operation = client.import_data(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.ImportDataRequest, dict]):
                 The request object. Request message for
@@ -717,7 +895,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, input_config])
         if request is not None and has_flattened_params:
@@ -778,6 +956,34 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_export_data():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                output_config = automl_v1.OutputConfig()
+                output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = automl_v1.ExportDataRequest(
+                    name="name_value",
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.export_data(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.ExportDataRequest, dict]):
                 The request object. Request message for
@@ -822,7 +1028,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, output_config])
         if request is not None and has_flattened_params:
@@ -879,6 +1085,25 @@ class AutoMlAsyncClient:
     ) -> annotation_spec.AnnotationSpec:
         r"""Gets an annotation spec.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_get_annotation_spec():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.GetAnnotationSpecRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_annotation_spec(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.GetAnnotationSpecRequest, dict]):
                 The request object. Request message for
@@ -901,7 +1126,7 @@ class AutoMlAsyncClient:
                 A definition of an annotation spec.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -963,6 +1188,30 @@ class AutoMlAsyncClient:
         are created for it: a global evaluation, and one evaluation for
         each annotation spec.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_create_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.CreateModelRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                operation = client.create_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.CreateModelRequest, dict]):
                 The request object. Request message for
@@ -996,7 +1245,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, model])
         if request is not None and has_flattened_params:
@@ -1053,6 +1302,25 @@ class AutoMlAsyncClient:
     ) -> model.Model:
         r"""Gets a model.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_get_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.GetModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_model(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.GetModelRequest, dict]):
                 The request object. Request message for
@@ -1075,7 +1343,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1132,6 +1400,26 @@ class AutoMlAsyncClient:
     ) -> pagers.ListModelsAsyncPager:
         r"""Lists models.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_list_models():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.ListModelsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_models(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.ListModelsRequest, dict]):
                 The request object. Request message for
@@ -1159,7 +1447,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1225,6 +1513,30 @@ class AutoMlAsyncClient:
         completes, and ``delete_details`` in the
         [metadata][google.longrunning.Operation.metadata] field.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_delete_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.DeleteModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.DeleteModelRequest, dict]):
                 The request object. Request message for
@@ -1262,7 +1574,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1328,6 +1640,24 @@ class AutoMlAsyncClient:
     ) -> gca_model.Model:
         r"""Updates a model.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_update_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.UpdateModelRequest(
+                )
+
+                # Make the request
+                response = client.update_model(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.UpdateModelRequest, dict]):
                 The request object. Request message for
@@ -1359,7 +1689,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([model, update_mask])
         if request is not None and has_flattened_params:
@@ -1423,6 +1753,30 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_deploy_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.DeployModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.deploy_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.DeployModelRequest, dict]):
                 The request object. Request message for
@@ -1460,7 +1814,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1523,6 +1877,30 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_undeploy_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.UndeployModelRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.undeploy_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.UndeployModelRequest, dict]):
                 The request object. Request message for
@@ -1560,7 +1938,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1623,6 +2001,34 @@ class AutoMlAsyncClient:
         [response][google.longrunning.Operation.response] field when it
         completes.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_export_model():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                output_config = automl_v1.ModelExportOutputConfig()
+                output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = automl_v1.ExportModelRequest(
+                    name="name_value",
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.export_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.ExportModelRequest, dict]):
                 The request object. Request message for
@@ -1669,7 +2075,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, output_config])
         if request is not None and has_flattened_params:
@@ -1726,6 +2132,25 @@ class AutoMlAsyncClient:
     ) -> model_evaluation.ModelEvaluation:
         r"""Gets a model evaluation.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_get_model_evaluation():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.GetModelEvaluationRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_model_evaluation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.GetModelEvaluationRequest, dict]):
                 The request object. Request message for
@@ -1748,7 +2173,7 @@ class AutoMlAsyncClient:
                 Evaluation results of a model.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1806,6 +2231,27 @@ class AutoMlAsyncClient:
     ) -> pagers.ListModelEvaluationsAsyncPager:
         r"""Lists model evaluations.
 
+        .. code-block::
+
+            from google.cloud import automl_v1
+
+            def sample_list_model_evaluations():
+                # Create a client
+                client = automl_v1.AutoMlClient()
+
+                # Initialize request argument(s)
+                request = automl_v1.ListModelEvaluationsRequest(
+                    parent="parent_value",
+                    filter="filter_value",
+                )
+
+                # Make the request
+                page_result = client.list_model_evaluations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.automl_v1.types.ListModelEvaluationsRequest, dict]):
                 The request object. Request message for
@@ -1854,7 +2300,7 @@ class AutoMlAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
