@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -115,6 +115,42 @@ class PredictionServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return PredictionServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> PredictionServiceTransport:
         """Returns the transport used by the client instance.
@@ -208,6 +244,30 @@ class PredictionServiceAsyncClient:
         -  Text Sentiment - TextSnippet, content up 500 characters,
            UTF-8 encoded.
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1beta1
+
+            def sample_predict():
+                # Create a client
+                client = automl_v1beta1.PredictionServiceClient()
+
+                # Initialize request argument(s)
+                payload = automl_v1beta1.ExamplePayload()
+                payload.image.image_bytes = b'image_bytes_blob'
+
+                request = automl_v1beta1.PredictRequest(
+                    name="name_value",
+                    payload=payload,
+                )
+
+                # Make the request
+                response = client.predict(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1beta1.types.PredictRequest, dict]):
                 The request object. Request message for
@@ -268,7 +328,7 @@ class PredictionServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, payload, params])
         if request is not None and has_flattened_params:
@@ -339,6 +399,30 @@ class PredictionServiceAsyncClient:
         -  Video Object Tracking \* Text Extraction
         -  Tables
 
+
+        .. code-block::
+
+            from google.cloud import automl_v1beta1
+
+            def sample_batch_predict():
+                # Create a client
+                client = automl_v1beta1.PredictionServiceClient()
+
+                # Initialize request argument(s)
+                request = automl_v1beta1.BatchPredictRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.batch_predict(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.automl_v1beta1.types.BatchPredictRequest, dict]):
                 The request object. Request message for
@@ -470,7 +554,7 @@ class PredictionServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, input_config, output_config, params])
         if request is not None and has_flattened_params:
