@@ -39,18 +39,29 @@ class DataType(proto.Message):
     r"""Indicated the type of data that can be stored in a structured
     data entity (e.g. a table).
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         list_element_type (google.cloud.automl_v1beta1.types.DataType):
             If
             [type_code][google.cloud.automl.v1beta1.DataType.type_code]
             == [ARRAY][google.cloud.automl.v1beta1.TypeCode.ARRAY], then
             ``list_element_type`` is the type of the elements.
+
+            This field is a member of `oneof`_ ``details``.
         struct_type (google.cloud.automl_v1beta1.types.StructType):
             If
             [type_code][google.cloud.automl.v1beta1.DataType.type_code]
             == [STRUCT][google.cloud.automl.v1beta1.TypeCode.STRUCT],
             then ``struct_type`` provides type information for the
             struct's fields.
+
+            This field is a member of `oneof`_ ``details``.
         time_format (str):
             If
             [type_code][google.cloud.automl.v1beta1.DataType.type_code]
@@ -67,6 +78,8 @@ class DataType(proto.Message):
                the Unix epoch); or be written in ``strftime`` syntax. If
                time_format is not set, then the default format as
                described on the type_code is used.
+
+            This field is a member of `oneof`_ ``details``.
         type_code (google.cloud.automl_v1beta1.types.TypeCode):
             Required. The
             [TypeCode][google.cloud.automl.v1beta1.TypeCode] for this
