@@ -102,11 +102,11 @@ class ListDatasetsRequest(proto.Message):
             An expression for filtering the results of the request.
 
             -  ``dataset_metadata`` - for existence of the case (e.g.
-               image_classification_dataset_metadata:*). Some examples
-               of using the filter are:
+               ``image_classification_dataset_metadata:*``). Some
+               examples of using the filter are:
 
             -  ``translation_dataset_metadata:*`` --> The dataset has
-               translation_dataset_metadata.
+               ``translation_dataset_metadata``.
         page_size (int):
             Requested page size. Server may return fewer
             results than requested. If unspecified, server
@@ -446,13 +446,13 @@ class ListModelsRequest(proto.Message):
             An expression for filtering the results of the request.
 
             -  ``model_metadata`` - for existence of the case (e.g.
-               video_classification_model_metadata:*).
+               ``video_classification_model_metadata:*``).
 
             -  ``dataset_id`` - for = or !=. Some examples of using the
                filter are:
 
             -  ``image_classification_model_metadata:*`` --> The model
-               has image_classification_model_metadata.
+               has ``image_classification_model_metadata``.
 
             -  ``dataset_id=5`` --> The model was created from a dataset
                with ID 5.
@@ -511,13 +511,24 @@ class DeployModelRequest(proto.Message):
     r"""Request message for
     [AutoMl.DeployModel][google.cloud.automl.v1beta1.AutoMl.DeployModel].
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         image_object_detection_model_deployment_metadata (google.cloud.automl_v1beta1.types.ImageObjectDetectionModelDeploymentMetadata):
             Model deployment metadata specific to Image
             Object Detection.
+
+            This field is a member of `oneof`_ ``model_deployment_metadata``.
         image_classification_model_deployment_metadata (google.cloud.automl_v1beta1.types.ImageClassificationModelDeploymentMetadata):
             Model deployment metadata specific to Image
             Classification.
+
+            This field is a member of `oneof`_ ``model_deployment_metadata``.
         name (str):
             Required. Resource name of the model to
             deploy.
